==> mdm-rpc-0.1.4-sources.jar: com/chinayanghe/msp/mdm/vo/terminal/TmRTermCustPosBGVo.java <==
package com.chinayanghe.msp.mdm.vo.terminal;

import java.io.Serializable;
import java.util.Date;

/**
 * 终端与岗位关联dto
 * @author shu
 * @version v1.0
 */
public class TmRTermCustPosBGVo implements Serializable {
	
	private static final long serialVersionUID = 1L;

	private String id;
	/** 终端编码*/
	private String terminalCode;
	/** 岗位编码*/
	private String relPositionCode;
	/** 人员编码*/
	private String posUserCode;
	/** 组织编码*/
	private String orgCode;
	/** 关系状态*/
	//01：认领待待审核  Enable：正常可用     Disable：停用
	private String relationState;
	//private
	/** 创建时间*/
	private Date createDate;
	/** 创建人ID*/
	private String createName;
	/** 修改时间*/
	private Date updateDate;
	/** 修改人*/
	private String updateName;
	/** 创建岗位*/
	private String positionCode;
	/** 创建岗位*/
	private String positionCodeUp;

	public String getTerminalCode() {
		return terminalCode;
	}

	public void setTerminalCode(String terminalCode) {
		this.terminalCode = terminalCode;
	}

	public String getRelPositionCode() {
		return relPositionCode;
	}

	public void setRelPositionCode(String relPositionCode) {
		this.relPositionCode = relPositionCode;
	}

	public String getPosUserCode() {
		return posUserCode;
	}

	public void setPosUserCode(String posUserCode) {
		this.posUserCode = posUserCode;
	}

	public String getOrgCode() {
		return orgCode;
	}

	public void setOrgCode(String orgCode) {
		this.orgCode = orgCode;
	}

	public String getRelationState() {
		return relationState;
	}

	public void setRelationState(String relationState) {
		this.relationState = relationState;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getUpdateDate() {
		return updateDate;
	}

	public void setUpdateDate(Date updateDate) {
		this.updateDate = updateDate;
	}

	public String getUpdateName() {
		return updateName;
	}

	public void setUpdateName(String updateName) {
		this.updateName = updateName;
	}

	public String getPositionCode() {
		return positionCode;
	}

	public void setPositionCode(String positionCode) {
		this.positionCode = positionCode;
	}

	public String getPositionCodeUp() {
		return positionCodeUp;
	}

	public void setPositionCodeUp(String positionCodeUp) {
		this.positionCodeUp = positionCodeUp;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}
}

==> mdm-rpc-0.1.11-sources.jar: com/chinayanghe/msp/mdm/vo/terminal/TmRTermCustPosBGVo.java <==
package com.chinayanghe.msp.mdm.vo.terminal;

import java.io.Serializable;
import java.util.Date;

/**
 * 终端与岗位关联dto
 * @author shu
 * @version v1.0
 */
public class TmRTermCustPosBGVo implements Serializable {
	
	private static final long serialVersionUID = 1L;

	private String id;
	/** 终端编码*/
	private String terminalCode;
	/** 岗位编码*/
	private String relPositionCode;
	/** 人员编码*/
	private String posUserCode;
	/** 组织编码*/
	private String orgCode;
	/** 分公司编码*/
	private String branchComCode;
	/** 关系状态*/
	//01：认领待待审核  Enable：正常可用     Disable：停用
	private String relationState;
	//private
	/** 创建时间*/
	private Date createDate;
	/** 创建人ID*/
	private String createName;
	/** 修改时间*/
	private Date updateDate;
	/** 修改人*/
	private String updateName;
	/** 创建岗位*/
	private String positionCode;
	/** 创建岗位*/
	private String positionCodeUp;

	public String getTerminalCode() {
		return terminalCode;
	}

	public void setTerminalCode(String terminalCode) {
		this.terminalCode = terminalCode;
	}

	public String getRelPositionCode() {
		return relPositionCode;
	}

	public void setRelPositionCode(String relPositionCode) {
		this.relPositionCode = relPositionCode;
	}

	public String getPosUserCode() {
		return posUserCode;
	}

	public void setPosUserCode(String posUserCode) {
		this.posUserCode = posUserCode;
	}

	public String getOrgCode() {
		return orgCode;
	}

	public void setOrgCode(String orgCode) {
		this.orgCode = orgCode;
	}

	public String getRelationState() {
		return relationState;
	}

	public void setRelationState(String relationState) {
		this.relationState = relationState;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getUpdateDate() {
		return updateDate;
	}

	public void setUpdateDate(Date updateDate) {
		this.updateDate = updateDate;
	}

	public String getUpdateName() {
		return updateName;
	}

	public void setUpdateName(String updateName) {
		this.updateName = updateName;
	}

	public String getPositionCode() {
		return positionCode;
	}

	public void setPositionCode(String positionCode) {
		this.positionCode = positionCode;
	}

	public String getPositionCodeUp() {
		return positionCodeUp;
	}

	public void setPositionCodeUp(String positionCodeUp) {
		this.positionCodeUp = positionCodeUp;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getBranchComCode() {
		return branchComCode;
	}

	public void setBranchComCode(String branchComCode) {
		this.branchComCode = branchComCode;
	}
}
